@@ -1,68 +1,77 @@
 # define methods ----------------------------------------------------------
 # init the statistical matrix
-init_REM_choice <- function(effectFun, network, attribute, n1, n2, cache = NULL)
+init_REM_choice <- function(effectFun, ...) {
   UseMethod("init_REM_choice", effectFun)
-
+}
 
 # default -----------------------------------------------------------------
 init_REM_choice.default <- function(
     effectFun,
     network = NULL, attribute = NULL,
     window,
-    n1, n2) {
+    n1, n2, ...) {
   init_DyNAM_choice.default(
     effectFun = effectFun,
     network = network, attribute = attribute,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
 }
 
 # Structural effects ------------------------------------------------------
 # tie ---------------------------------------------------------------------
-init_REM_choice.tie <- function(effectFun, network, window, n1, n2)
-  init_DyNAM_choice.tie(effectFun = effectFun, network = network,
-                        window = window, n1 = n1, n2 = n2)
+init_REM_choice.tie <- function(effectFun, network, window, n1, n2, ...) {
+  init_DyNAM_choice.tie(
+    effectFun = effectFun, network = network,
+    window = window, n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_tie <- function(
     network,
     sender, receiver, replace,
-    weighted = FALSE, transformFun = identity)
+    weighted = FALSE, transformFun = identity) {
   update_DyNAM_choice_tie(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     weighted = weighted, transformFun = transformFun
   )
-
+}
 
 # inertia -----------------------------------------------------------------
-init_REM_choice.inertia <- function(effectFun, network, window, n1, n2)
-  init_REM_choice.tie(effectFun = effectFun, network = network,
-                      window = window, n1 = n1, n2 = n2)
-
+init_REM_choice.inertia <- function(effectFun, network, window, n1, n2, ...) {
+  init_REM_choice.tie(
+    effectFun = effectFun, network = network,
+    window = window, n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_inertia <- function(
     network,
     sender, receiver, replace,
-    weighted = FALSE, transformFun = identity)
+    weighted = FALSE, transformFun = identity) {
   update_REM_choice_tie(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     weighted = weighted, transformFun = transformFun
   )
+}
 
 # recip -------------------------------------------------------------------
-init_REM_choice.recip <- function(effectFun, network, window, n1, n2)
+init_REM_choice.recip <- function(effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.recip(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_recip <- function(
     network,
     sender, receiver, replace,
     isTwoMode = FALSE,
     weighted = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_recip(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
@@ -70,6 +79,7 @@ update_REM_choice_recip <- function(
     weighted = weighted,
     transformFun = transformFun
   )
+}
 
 # indeg -------------------------------------------------------------------
 #' init stat matrix indegree using cache
@@ -98,8 +108,9 @@ update_REM_choice_recip <- function(
 #'   nrow = 5, ncol = 6, byrow = TRUE
 #' )
 #' effectFUN <- function(
-#'   weighted = TRUE, isTwoMode = TRUE, transformFun = identity)
+#'     weighted = TRUE, isTwoMode = TRUE, transformFun = identity) {
 #'   NULL
+#' }
 #' init_REM_choice.indeg(effectFUN, network, NULL, 5, 6)
 #' network <- matrix(
 #'   c(
@@ -112,18 +123,20 @@ update_REM_choice_recip <- function(
 #'   nrow = 5, ncol = 5, byrow = TRUE
 #' )
 #' effectFUN <- function(
-#'   weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
-#'   type = "ego")
+#'     weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
+#'     type = "ego") {
 #'   NULL
+#' }
 #' init_REM_choice.indeg(effectFUN, network, NULL, 5, 5)
 #'
 #' effectFUN <- function(
-#'   weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
-#'   type = "alter")
+#'     weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
+#'     type = "alter") {
 #'   NULL
+#' }
 #' init_REM_choice.indeg(effectFUN, network, NULL, 5, 5)
 #' }
-init_REM_choice.indeg <- function(effectFun, network, window, n1, n2) {
+init_REM_choice.indeg <- function(effectFun, network, window, n1, n2, ...) {
   # Get arguments
   params <- formals(effectFun)
   weighted <- eval(params[["weighted"]])
@@ -133,20 +146,23 @@ init_REM_choice.indeg <- function(effectFun, network, window, n1, n2) {
 
   if (isTwoMode && type == "ego") {
     stop(dQuote("indeg"),
-         "effect must not use for type 'ego' (type = 'ego') when is ",
-         "a two-mode network (isTwoMode = TRUE) ", call. = FALSE)
+      "effect must not use for type 'ego' (type = 'ego') when is ",
+      "a two-mode network (isTwoMode = TRUE) ",
+      call. = FALSE
+    )
   }
   # has window or is empty initialize empty
   if ((!is.null(window) && !is.infinite(window)) || all(network == 0)) {
     return(list(
       cache = numeric(n2),
       stat = matrix(forceAndCall(1, funApply, 0), nrow = n1, ncol = n2)
-      ))
+    ))
   }
 
   # indeg as colsums
   cache <- .colSums(if (weighted) network else network > 0, n1, n2,
-                    na.rm = TRUE)
+    na.rm = TRUE
+  )
 
   # applied transformFun instead
   stat <- forceAndCall(1, funApply, cache)
@@ -197,13 +213,15 @@ init_REM_choice.indeg <- function(effectFun, network, window, n1, n2) {
 #'   network,
 #'   1, 2, 3,
 #'   cache, 5, 6,
-#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "ego")
+#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "ego"
+#' )
 #'
 #' update_REM_choice_indeg(
 #'   network,
 #'   1, 2, 3,
 #'   cache, 5, 6,
-#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "al")
+#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "al"
+#' )
 #' }
 update_REM_choice_indeg <- function(
     network,
@@ -238,8 +256,11 @@ update_REM_choice_indeg <- function(
 
   if (type == "alter") {
     # when the cache had change
-    if (isTwoMode) other <- seq_len(n1) else
-       other <- setdiff(seq_len(n1), receiver)
+    if (isTwoMode) {
+      other <- seq_len(n1)
+    } else {
+      other <- setdiff(seq_len(n1), receiver)
+    }
 
     changes <- cbind(
       node1 = other,
@@ -248,8 +269,11 @@ update_REM_choice_indeg <- function(
     )
   } else if (type == "ego") {
     # when the cache had change
-    if (isTwoMode) other <- seq_len(n2) else
-       other <- setdiff(seq_len(n2), receiver)
+    if (isTwoMode) {
+      other <- seq_len(n2)
+    } else {
+      other <- setdiff(seq_len(n2), receiver)
+    }
 
     changes <- cbind(
       node1 = receiver,
@@ -288,8 +312,9 @@ update_REM_choice_indeg <- function(
 #'   nrow = 5, ncol = 6, byrow = TRUE
 #' )
 #' effectFUN <- function(
-#'   weighted = TRUE, isTwoMode = TRUE, transformFun = identity)
+#'     weighted = TRUE, isTwoMode = TRUE, transformFun = identity) {
 #'   NULL
+#' }
 #' init_REM_choice.outdeg(effectFUN, network, NULL, 5, 6)
 #' network <- matrix(
 #'   c(
@@ -302,18 +327,20 @@ update_REM_choice_indeg <- function(
 #'   nrow = 5, ncol = 5, byrow = TRUE
 #' )
 #' effectFUN <- function(
-#'   weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
-#'   type = "ego")
+#'     weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
+#'     type = "ego") {
 #'   NULL
+#' }
 #' init_REM_choice.outdeg(effectFUN, network, 1, 5, 5)
 #'
 #' effectFUN <- function(
-#'   weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
-#'   type = "alter")
+#'     weighted = TRUE, isTwoMode = FALSE, transformFun = identity,
+#'     type = "alter") {
 #'   NULL
+#' }
 #' init_REM_choice.outdeg(effectFUN, network, NULL, 5, 5)
 #' }
-init_REM_choice.outdeg <- function(effectFun, network, window, n1, n2) {
+init_REM_choice.outdeg <- function(effectFun, network, window, n1, n2, ...) {
   # Get arguments
   params <- formals(effectFun)
   weighted <- eval(params[["weighted"]])
@@ -325,7 +352,9 @@ init_REM_choice.outdeg <- function(effectFun, network, window, n1, n2) {
     stop(
       dQuote("outdeg"),
       "effect must not use for type 'alter' (type = 'alter') when is ",
-      "a two-mode network (isTwoMode = TRUE) ", call. = FALSE)
+      "a two-mode network (isTwoMode = TRUE) ",
+      call. = FALSE
+    )
   }
   # has window or is empty initialize empty
   if ((!is.null(window) && !is.infinite(window)) || all(network == 0)) {
@@ -336,7 +365,8 @@ init_REM_choice.outdeg <- function(effectFun, network, window, n1, n2) {
   }
   # indeg as colsums
   cache <- .rowSums(if (weighted) network else network > 0, n1, n2,
-                    na.rm = TRUE)
+    na.rm = TRUE
+  )
 
   # applied transformFun instead
   stat <- forceAndCall(1, funApply, cache)
@@ -387,13 +417,15 @@ init_REM_choice.outdeg <- function(effectFun, network, window, n1, n2) {
 #'   network,
 #'   1, 2, 3,
 #'   cache, 5, 6,
-#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "ego")
+#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "ego"
+#' )
 #'
 #' update_REM_choice_outdeg(
 #'   network,
 #'   1, 2, 3,
 #'   cache, 5, 6,
-#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "al")
+#'   isTwoMode = TRUE, weighted = TRUE, transformFun = sqrt, type = "al"
+#' )
 #' }
 update_REM_choice_outdeg <- function(
     network,
@@ -429,8 +461,11 @@ update_REM_choice_outdeg <- function(
 
   if (type == "alter") {
     # when the cache had change
-    if (isTwoMode) other <- seq_len(n1) else
+    if (isTwoMode) {
+      other <- seq_len(n1)
+    } else {
       other <- setdiff(seq_len(n1), sender)
+    }
 
     changes <- cbind(
       node1 = other,
@@ -439,8 +474,11 @@ update_REM_choice_outdeg <- function(
     )
   } else if (type == "ego") {
     # when the cache had change
-    if (isTwoMode) other <- seq_len(n2) else
+    if (isTwoMode) {
+      other <- seq_len(n2)
+    } else {
       other <- setdiff(seq_len(n2), sender)
+    }
 
     changes <- cbind(
       node1 = sender,
@@ -452,11 +490,13 @@ update_REM_choice_outdeg <- function(
 }
 
 # trans -------------------------------------------------------------------
-init_REM_choice.trans <- function(effectFun, network, window, n1, n2)
+init_REM_choice.trans <- function(effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.trans(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_trans <- function(
     network,
@@ -464,20 +504,23 @@ update_REM_choice_trans <- function(
     receiver,
     replace, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_trans(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # cycle -------------------------------------------------------------------
-init_REM_choice.cycle <- function(effectFun, network, window, n1, n2)
+init_REM_choice.cycle <- function(effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.cycle(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_cycle <- function(
     network,
@@ -485,20 +528,24 @@ update_REM_choice_cycle <- function(
     receiver,
     replace, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_cycle(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # common receiver ---------------------------------------------------------
-init_REM_choice.commonReceiver <- function(effectFun, network, window, n1, n2)
+init_REM_choice.commonReceiver <- function(
+    effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.commonReceiver(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_commonReceiver <- function(
     network,
@@ -506,20 +553,24 @@ update_REM_choice_commonReceiver <- function(
     receiver,
     replace, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_commonReceiver(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # common sender -----------------------------------------------------------
-init_REM_choice.commonSender <- function(effectFun, network, window, n1, n2)
+init_REM_choice.commonSender <- function(
+    effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.commonSender(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_commonSender <- function(
     network,
@@ -527,21 +578,24 @@ update_REM_choice_commonSender <- function(
     receiver,
     replace, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_commonSender(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
-
+}
 
 # mixedTrans --------------------------------------------------------------
-init_REM_choice.mixedTrans <- function(effectFun, network, window, n1, n2)
+init_REM_choice.mixedTrans <- function(
+    effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.mixedTrans(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_mixedTrans <- function(
     network,
@@ -549,20 +603,24 @@ update_REM_choice_mixedTrans <- function(
     receiver,
     replace, netUpdate, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_mixedTrans(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     netUpdate = netUpdate, cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # mixedCycle --------------------------------------------------------------
-init_REM_choice.mixedCycle <- function(effectFun, network, window, n1, n2)
+init_REM_choice.mixedCycle <- function(
+    effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.mixedCycle(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_mixedCycle <- function(
     network,
@@ -570,21 +628,24 @@ update_REM_choice_mixedCycle <- function(
     receiver,
     replace, netUpdate, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_mixedCycle(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     netUpdate = netUpdate, cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # mixed common receiver ---------------------------------------------------
-init_REM_choice.mixedCommonReceiver <- function(effectFun, network,
-                                                window, n1, n2)
+init_REM_choice.mixedCommonReceiver <- function(
+    effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.mixedCommonReceiver(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_mixedCommonReceiver <- function(
     network,
@@ -592,21 +653,24 @@ update_REM_choice_mixedCommonReceiver <- function(
     receiver,
     replace, netUpdate, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_mixedCommonReceiver(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     netUpdate = netUpdate, cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # mixed common sender -----------------------------------------------------
-init_REM_choice.mixedCommonSender <- function(effectFun, network,
-                                              window, n1, n2)
+init_REM_choice.mixedCommonSender <- function(
+    effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.mixedCommonSender(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_mixedCommonSender <- function(
     network,
@@ -614,27 +678,30 @@ update_REM_choice_mixedCommonSender <- function(
     receiver,
     replace, netUpdate, cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_mixedCommonSender(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
     netUpdate = netUpdate, cache = cache,
     isTwoMode = isTwoMode, transformFun = transformFun
   )
+}
 
 # four --------------------------------------------------------------------
-init_REM_choice.four <- function(effectFun, network, window, n1, n2)
+init_REM_choice.four <- function(effectFun, network, window, n1, n2, ...) {
   init_DyNAM_choice.four(
     effectFun = effectFun, network = network,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2, ...
+  )
+}
 
 update_REM_choice_four <- function(
     network,
     sender, receiver, replace,
     cache,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_four(
     network = network,
     sender = sender, receiver = receiver, replace = replace,
@@ -642,6 +709,8 @@ update_REM_choice_four <- function(
     isTwoMode = isTwoMode,
     transformFun = transformFun
   )
+}
+
 # tertius ----------------------------------------------------------------
 #' init stat matrix tertius using cache
 #'
@@ -672,13 +741,14 @@ update_REM_choice_four <- function(
 #' )
 #' attribute <- c(1, 0, 1, 3, 1)
 #' effectFUN <- function(
-#'   type = "alter", isTwoMode = TRUE,
-#'   transformFun = abs, aggregateFun = function(x) median(x, na.rm = TRUE))
+#'     type = "alter", isTwoMode = TRUE,
+#'     transformFun = abs, aggregateFun = function(x) median(x, na.rm = TRUE)) {
 #'   NULL
+#' }
 #' init_REM_choice.tertius(effectFUN, network, attribute)
 #' }
-init_REM_choice.tertius <- function(effectFun, network, attribute,
-                                    window, n1, n2) {
+init_REM_choice.tertius <- function(
+    effectFun, network, attribute, window, n1, n2, ...) {
   # Get arguments
   params <- formals(effectFun)
   aggFun <- eval(params[["aggregateFun"]])
@@ -688,7 +758,9 @@ init_REM_choice.tertius <- function(effectFun, network, attribute,
 
   if (isTwoMode && type == "ego") {
     stop("'tertius' effect must not use for type 'ego' (type = 'ego') when is ",
-         "a two-mode network (isTwoMode = TRUE) ", call. = FALSE)
+      "a two-mode network (isTwoMode = TRUE) ",
+      call. = FALSE
+    )
   }
   # if (anyNA(network)) network[is.na(network)] <- 0
   # has window or is empty initialize empty
@@ -701,15 +773,19 @@ init_REM_choice.tertius <- function(effectFun, network, attribute,
   # always weighted
   network <- sign(unname(network))
   # compute cache[j]: agg_{k \in N^-(j)}(z_k) || NA if N^-(j) == \empty
-  cache <- apply(X = network, MARGIN = 2,
-                FUN = function(x) {
-                  # # inNeighbor of j
-                  inReceiver <- which(x == 1)
-                  # # not aggregated if not inNeighbor(j)
-                  if (length(inReceiver) == 0) return(NA_real_)
-                  # # apply aggFun to inNeighbor(j)
-                  forceAndCall(1, aggFun, attribute[inReceiver])
-                })
+  cache <- apply(
+    X = network, MARGIN = 2,
+    FUN = function(x) {
+      # # inNeighbor of j
+      inReceiver <- which(x == 1)
+      # # not aggregated if not inNeighbor(j)
+      if (length(inReceiver) == 0) {
+        return(NA_real_)
+      }
+      # # apply aggFun to inNeighbor(j)
+      forceAndCall(1, aggFun, attribute[inReceiver])
+    }
+  )
   # applied transformFun
   stat <- forceAndCall(1, funApply, cache)
   # impute missing values by the average
@@ -762,36 +838,38 @@ init_REM_choice.tertius <- function(effectFun, network, attribute,
 #' cache <- c(2, 1, 0, 1, 0, 2)
 #'
 #' update_REM_choice_tertius(network, attribute,
-#'                           sender = 2, receiver = 3,
-#'                           node = NULL,
-#'                           3,
-#'                           cache,
-#'                           n1 = 5, n2 = 6,
-#'                           transformFun = function(x) x ^ 2,
-#'                           aggregateFun = function(x) median(x, na.rm = TRUE))
+#'   sender = 2, receiver = 3,
+#'   node = NULL,
+#'   3,
+#'   cache,
+#'   n1 = 5, n2 = 6,
+#'   transformFun = function(x) x^2,
+#'   aggregateFun = function(x) median(x, na.rm = TRUE)
+#' )
 #'
 #' update_REM_choice_tertius(network, attribute,
-#'                           sender = NULL, receiver = NULL,
-#'                           node = 3,
-#'                           3,
-#'                           cache,
-#'                           n1 = 5, n2 = 6,
-#'                           transformFun = function(x) x ^ 2,
-#'                           aggregateFun = function(x) median(x, na.rm = TRUE))
+#'   sender = NULL, receiver = NULL,
+#'   node = 3,
+#'   3,
+#'   cache,
+#'   n1 = 5, n2 = 6,
+#'   transformFun = function(x) x^2,
+#'   aggregateFun = function(x) median(x, na.rm = TRUE)
+#' )
 #' }
 update_REM_choice_tertius <- function(
-  network,
-  attribute,
-  sender = NULL,
-  receiver = NULL,
-  node = NULL,
-  replace,
-  cache,
-  n1 = n1, n2 = n2,
-  isTwoMode = FALSE,
-  type = c("alter", "ego"),
-  transformFun = identity,
-  aggregateFun = function(x) mean(x, na.rm = TRUE)) {
+    network,
+    attribute,
+    sender = NULL,
+    receiver = NULL,
+    node = NULL,
+    replace,
+    cache,
+    n1 = n1, n2 = n2,
+    isTwoMode = FALSE,
+    type = c("alter", "ego"),
+    transformFun = identity,
+    aggregateFun = function(x) mean(x, na.rm = TRUE)) {
   type <- match.arg(type)
   # utility functions to return third nodes
   third <- function(n, diff = c(node)) {
@@ -831,7 +909,8 @@ update_REM_choice_tertius <- function(
     # change stat
     valChangeCache <- forceAndCall(
       1, aggregateFun,
-      if (length(inReceiver) > 0) attribute[inReceiver] else NA)
+      if (length(inReceiver) > 0) attribute[inReceiver] else NA
+    )
     # changes case 1: all nodes needs to be update the att[i] - cache[j] values
     # if (isTwoMode) seq_len(n2) else third(n1, receiver)
     nodesChange <- if (!is.na(valChangeCache)) receiver else numeric()
@@ -857,14 +936,16 @@ update_REM_choice_tertius <- function(
     outNode <- which(network[node, ] > 0)
 
     cache[outNode] <-
-      vapply(X = outNode,
-             FUN =  function(x) {
-               # # inNeighbor of outNode, excluding Node because has a new value
-               inReceiver <- setdiff(which(network[, x] > 0), node)
-               # # apply aggFun to inNeighbor(outNode)
-               forceAndCall(1, aggregateFun, c(attribute[inReceiver], replace))
-             },
-             FUN.VALUE = double(1))
+      vapply(
+        X = outNode,
+        FUN = function(x) {
+          # # inNeighbor of outNode, excluding Node because has a new value
+          inReceiver <- setdiff(which(network[, x] > 0), node)
+          # # apply aggFun to inNeighbor(outNode)
+          forceAndCall(1, aggregateFun, c(attribute[inReceiver], replace))
+        },
+        FUN.VALUE = double(1)
+      )
 
     # changes case 2: is an update value for node,
     #   then its update is done separately
@@ -877,12 +958,13 @@ update_REM_choice_tertius <- function(
       rbind,
       lapply(
         nodesChange,
-        function(x)
+        \(x) {
           cbind(
             node1 = if (isTwoMode) seq_len(n1) else third(n1, x),
             node2 = x,
             replace = forceAndCall(1, transformFun, cache[x])
           )
+        }
       )
     )
   } else if (type == "ego") {
@@ -891,12 +973,13 @@ update_REM_choice_tertius <- function(
       rbind,
       lapply(
         nodesChange,
-        function(x)
+        \(x) {
           cbind(
             node1 = x,
             node2 = if (isTwoMode) seq_len(n1) else third(n1, x),
             replace = forceAndCall(1, transformFun, cache[x])
           )
+        }
       )
     )
   }
@@ -913,12 +996,13 @@ update_REM_choice_tertius <- function(
           rbind,
           lapply(
             toImpute,
-            function(x)
+            \(x) {
               cbind(
                 node1 = if (isTwoMode) seq_len(n1) else third(n1, x),
                 node2 = x,
                 replace = forceAndCall(1, transformFun, imputeVal)
               )
+            }
           )
         )
       )
@@ -930,12 +1014,13 @@ update_REM_choice_tertius <- function(
           rbind,
           lapply(
             toImpute,
-            function(x)
+            \(x) {
               cbind(
                 node1 = x,
                 node2 = if (isTwoMode) seq_len(n1) else third(n1, x),
                 replace = forceAndCall(1, transformFun, imputeVal)
               )
+            }
           )
         )
       )
@@ -973,17 +1058,20 @@ update_REM_choice_tertius <- function(
 #' )
 #' attribute <- c(1, 0, 1, 3, 1)
 #' effectFUN <- function(transformFun = abs,
-#'                       aggregateFun = function(x) median(x, na.rm = TRUE))
+#'                       aggregateFun = function(x) median(x, na.rm = TRUE)) {
 #'   NULL
+#' }
 #' init_REM_choice.tertiusDiff(effectFUN, network, attribute)
 #' }
-init_REM_choice.tertiusDiff <- function(effectFun, network, attribute,
-                                        window, n1, n2)
+init_REM_choice.tertiusDiff <- function(
+    effectFun, network, attribute, window, n1, n2, ...) {
   init_DyNAM_choice.tertiusDiff(
     effectFun = effectFun,
     network = network, attribute = attribute,
     window = window,
-    n1 = n1, n2 = n2)
+    n1 = n1, n2 = n2
+  )
+}
 
 #' update stat transitivity using cache
 #'
@@ -1026,8 +1114,9 @@ init_REM_choice.tertiusDiff <- function(effectFun, network, attribute,
 #'   3,
 #'   cache,
 #'   n1 = 5, n2 = 6,
-#'   transformFun = function(x) x ^ 2,
-#'   aggregateFun = function(x) median(x, na.rm = TRUE))
+#'   transformFun = function(x) x^2,
+#'   aggregateFun = function(x) median(x, na.rm = TRUE)
+#' )
 #'
 #' update_REM_choice_tertiusDiff(
 #'   network, attribute,
@@ -1036,21 +1125,22 @@ init_REM_choice.tertiusDiff <- function(effectFun, network, attribute,
 #'   3,
 #'   cache,
 #'   n1 = 5, n2 = 6,
-#'   transformFun = function(x) x ^ 2,
-#'   aggregateFun = function(x) median(x, na.rm = TRUE))
+#'   transformFun = function(x) x^2,
+#'   aggregateFun = function(x) median(x, na.rm = TRUE)
+#' )
 #' }
 update_REM_choice_tertiusDiff <- function(
-  network,
-  attribute,
-  sender = NULL,
-  receiver = NULL,
-  node = NULL,
-  replace,
-  cache,
-  isTwoMode = FALSE,
-  n1 = n1, n2 = n2,
-  transformFun = abs,
-  aggregateFun = function(x) mean(x, na.rm = TRUE))
+    network,
+    attribute,
+    sender = NULL,
+    receiver = NULL,
+    node = NULL,
+    replace,
+    cache,
+    isTwoMode = FALSE,
+    n1 = n1, n2 = n2,
+    transformFun = abs,
+    aggregateFun = function(x) mean(x, na.rm = TRUE)) {
   update_DyNAM_choice_tertiusDiff(
     network = network,
     attribute = attribute,
@@ -1062,20 +1152,24 @@ update_REM_choice_tertiusDiff <- function(
     isTwoMode = isTwoMode,
     n1 = n1, n2 = n2,
     transformFun = transformFun,
-    aggregateFun = aggregateFun)
-
+    aggregateFun = aggregateFun
+  )
+}
 
 # nodeTrans ------------------------------------------------------------------
 
 #' node trans init
-#' number of transitive triangles i->j->k;i->k where node i is embedded. Source node
-#' @param effectFun function with additional parameters isTwoMode, transformFun, type
+#' number of transitive triangles i->j->k;i->k where node i is embedded.
+#' Source node
+#' @param effectFun function with additional parameters isTwoMode, transformFun,
+#'  type, etc.
 #' @param network matrix n1*n2
 #' @param window NULL|numeric size of the window
 #' @param n1 integer nrow(network)
 #' @param n2 integer ncol(network)
 #'
-#' @return list with named components: cache numeric vector size n2, stat matrix numeric n1*n2
+#' @return list with named components: cache numeric vector size n2,
+#'  stat matrix numeric n1*n2
 #' @noRd
 #'
 #' @examples
@@ -1092,26 +1186,30 @@ update_REM_choice_tertiusDiff <- function(
 #'   nrow = 5, ncol = 5, byrow = TRUE
 #' )
 #' effectFUN <- function(
-#'   isTwoMode = TRUE, transformFun = identity, type = "ego")
+#'     isTwoMode = TRUE, transformFun = identity, type = "ego") {
 #'   NULL
+#' }
 #' init_REM_choice.nodeTrans(effectFUN, network, NULL, 5, 5)
 #'
 #' effectFUN <- function(
-#'   isTwoMode = FALSE, transformFun = identity, type = "ego")
+#'     isTwoMode = FALSE, transformFun = identity, type = "ego") {
 #'   NULL
+#' }
 #' init_REM_choice.nodeTrans(effectFUN, network, NULL, 5, 5)
 #'
 #' effectFUN <- function(
-#'   isTwoMode = FALSE, transformFun = identity, type = "alter")
+#'     isTwoMode = FALSE, transformFun = identity, type = "alter") {
 #'   NULL
+#' }
 #' init_REM_choice.nodeTrans(effectFUN, network, NULL, 5, 5)
 #'
 #' effectFUN <- function(
-#'   isTwoMode = FALSE, transformFun = identity, type = "alter")
+#'     isTwoMode = FALSE, transformFun = identity, type = "alter") {
 #'   NULL
+#' }
 #' init_REM_choice.nodeTrans(effectFUN, network, 9, 5, 5)
 #' }
-init_REM_choice.nodeTrans <- function(effectFun, network, window, n1, n2) {
+init_REM_choice.nodeTrans <- function(effectFun, network, window, n1, n2, ...) {
   # Get arguments
   params <- formals(effectFun)
   isTwoMode <- eval(params[["isTwoMode"]])
@@ -1120,7 +1218,9 @@ init_REM_choice.nodeTrans <- function(effectFun, network, window, n1, n2) {
 
   if (isTwoMode) {
     stop("'nodeTrans' effect must not use ",
-         "when is a two-mode network (isTwoMode = TRUE)", call. = FALSE)
+      "when is a two-mode network (isTwoMode = TRUE)",
+      call. = FALSE
+    )
   }
 
   # has window or is empty initialize empty
@@ -1135,11 +1235,13 @@ init_REM_choice.nodeTrans <- function(effectFun, network, window, n1, n2) {
 
   # compute stat: number of triangles i->j->k, i->k from i perspective
   # stat <- diag(tcrossprod(network %*% network, network))
-  cache <- .rowSums((network %*% network) * network, m = n1, n = n2,
-                    na.rm = TRUE)
+  cache <- .rowSums((network %*% network) * network,
+    m = n1, n = n2,
+    na.rm = TRUE
+  )
 
   stat <- matrix(forceAndCall(1, funApply, cache),
-                 nrow = n1, ncol = n2, byrow = (type == "alter")
+    nrow = n1, ncol = n2, byrow = (type == "alter")
   )
   # if (!isTwoMode)
   diag(stat) <- 0
@@ -1234,10 +1336,12 @@ update_REM_choice_nodeTrans <- function(
     replaceValues <- (replace - oldValue) * senderChanges + cache[sender]
     if (type == "ego") {
       changes <- cbind(
-        node1 = sender, node2 = third(n1, sender), replace = replaceValues)
+        node1 = sender, node2 = third(n1, sender), replace = replaceValues
+      )
     } else {
       changes <- cbind(
-        node1 = third(n1, sender), node2 = sender, replace = replaceValues)
+        node1 = third(n1, sender), node2 = sender, replace = replaceValues
+      )
     }
     cache[sender] <- replaceValues
   }
@@ -1250,7 +1354,7 @@ update_REM_choice_nodeTrans <- function(
         rbind,
         lapply(
           seq_along(commonSenders),
-          function(x)
+          \(x) {
             if (type == "ego") {
               cbind(
                 node1 = commonSenders[x],
@@ -1264,6 +1368,7 @@ update_REM_choice_nodeTrans <- function(
                 replace = replaceValues[x]
               )
             }
+          }
         )
       )
     )
@@ -1279,7 +1384,7 @@ update_REM_choice_nodeTrans <- function(
 
 # Covariate effects -------------------------------------------------------
 # ego ---------------------------------------------------------------------
-init_REM_choice.ego <- function(effectFun, attribute, n1, n2) {
+init_REM_choice.ego <- function(effectFun, attribute, n1, n2, ...) {
   # Get arguments
   params <- formals(effectFun)
   isTwoMode <- eval(params[["isTwoMode"]])
@@ -1321,45 +1426,51 @@ update_REM_choice_ego <- function(
 }
 
 # alter -------------------------------------------------------------------
-init_REM_choice.alter <- function(effectFun, attribute, n1, n2)
+init_REM_choice.alter <- function(effectFun, attribute, n1, n2, ...) {
   init_DyNAM_choice.alter(
-    effectFun = effectFun, attribute = attribute, n1 = n2, n2 = n2)
+    effectFun = effectFun, attribute = attribute, n1 = n2, n2 = n2, ...
+  )
+}
 
 update_REM_choice_alter <- function(
-  attribute,
-  node, replace,
-  n1, n2,
-  isTwoMode = FALSE)
+    attribute,
+    node, replace,
+    n1, n2,
+    isTwoMode = FALSE) {
   update_DyNAM_choice_alter(
     attribute = attribute,
     node = node, replace = replace,
     n1 = n1, n2 = n2,
     isTwoMode = isTwoMode
   )
+}
 
 # same --------------------------------------------------------------------
-init_REM_choice.same <- function(effectFun, attribute)
-  init_DyNAM_choice.same(effectFun = effectFun, attribute = attribute)
+init_REM_choice.same <- function(effectFun, attribute, ...) {
+  init_DyNAM_choice.same(effectFun = effectFun, attribute = attribute, ...)
+}
 
 update_REM_choice_same <- function(
     attribute,
     node, replace,
-    isTwoMode = FALSE)
+    isTwoMode = FALSE) {
   update_DyNAM_choice_same(
     attribute = attribute,
     node = node, replace = replace,
     isTwoMode = isTwoMode
   )
+}
 
 # diff --------------------------------------------------------------------
-init_REM_choice.diff <- function(effectFun, attribute)
-  init_DyNAM_choice.diff(effectFun = effectFun, attribute = attribute)
+init_REM_choice.diff <- function(effectFun, attribute, ...) {
+  init_DyNAM_choice.diff(effectFun = effectFun, attribute = attribute, ...)
+}
 
 update_REM_choice_diff <- function(
     attribute, node, replace,
     n1, n2,
     isTwoMode = FALSE,
-    transformFun = abs)
+    transformFun = abs) {
   update_DyNAM_choice_diff(
     attribute = attribute,
     node = node, replace = replace,
@@ -1367,16 +1478,18 @@ update_REM_choice_diff <- function(
     n1 = n1, n2 = n2,
     transformFun = transformFun
   )
+}
 
 # sim ---------------------------------------------------------------------
-init_REM_choice.sim <- function(effectFun, attribute)
-  init_DyNAM_choice.sim(effectFun = effectFun, attribute = attribute)
+init_REM_choice.sim <- function(effectFun, attribute, ...) {
+  init_DyNAM_choice.sim(effectFun = effectFun, attribute = attribute, ...)
+}
 
 update_REM_choice_sim <- function(
     attribute, node, replace,
     n1, n2,
     isTwoMode = FALSE,
-    transformFun = abs)
+    transformFun = abs) {
   update_DyNAM_choice_sim(
     attribute = attribute,
     node = node, replace = replace,
@@ -1384,18 +1497,19 @@ update_REM_choice_sim <- function(
     isTwoMode = isTwoMode,
     transformFun = transformFun
   )
-
+}
 
 # ego alter interaction ---------------------------------------------------
-init_REM_choice.egoAlterInt <- function(effectFun, attribute)
-  init_DyNAM_choice.sim(effectFun = effectFun, attribute = attribute)
+init_REM_choice.egoAlterInt <- function(effectFun, attribute, ...) {
+  init_DyNAM_choice.sim(effectFun = effectFun, attribute = attribute, ...)
+}
 
 update_REM_choice_egoAlterInt <- function(
     attribute, node, replace,
     attUpdate,
     n1, n2,
     isTwoMode = FALSE,
-    transformFun = identity)
+    transformFun = identity) {
   update_DyNAM_choice_egoAlterInt(
     attribute = attribute,
     node = node, replace = replace,
@@ -1404,3 +1518,4 @@ update_REM_choice_egoAlterInt <- function(
     isTwoMode = isTwoMode,
     transformFun = transformFun
   )
+}
