@@ -21,31 +21,27 @@
 #'
 #' @return a list of class preprocessed.goldfish
 #'
-#' @importFrom methods is
-#' @importFrom utils setTxtProgressBar getTxtProgressBar object.size
-#' @importFrom utils txtProgressBar
-#' @importFrom stats time
 #' @noRd
 preprocess <- function(
-  model,
-  subModel,
-  events,
-  effects,
-  windowParameters,
-  eventsObjectsLink,
-  eventsEffectsLink,
-  objectsEffectsLink,
-  # multipleParameter,
-  nodes,
-  nodes2 = nodes,
-  isTwoMode,
-  # add more parameters
-  startTime = min(vapply(events, function(x) min(x$time), double(1))),
-  endTime = max(vapply(events, function(x) max(x$time), double(1))),
-  rightCensored = FALSE,
-  progress = FALSE,
-  prepEnvir = new.env()) {
-
+    model,
+    subModel,
+    events,
+    effects,
+    windowParameters,
+    ignoreRepParameter,
+    eventsObjectsLink,
+    eventsEffectsLink,
+    objectsEffectsLink,
+    # multipleParameter,
+    nodes,
+    nodes2 = nodes,
+    isTwoMode,
+    # add more parameters
+    startTime = min(vapply(events, function(x) min(x$time), double(1))),
+    endTime = max(vapply(events, function(x) max(x$time), double(1))),
+    rightCensored = FALSE,
+    progress = FALSE,
+    prepEnvir = new.env()) {
   # For debugging
   # if (identical(environment(), globalenv())) {
   #   startTime <- min(vapply(events, function(x) min(x$time), double(1)))
@@ -65,36 +61,56 @@ preprocess <- function(
   hasStartTime <- FALSE
   isValidEvent <- TRUE
 
-  eventsMin <- min(vapply(events, function(x) min(x$time), double(1)))
-  eventsMax <- max(vapply(events, function(x) max(x$time), double(1)))
+  isWindowEffect <- !vapply(windowParameters, is.null, logical(1))
+  whichEventNoWindowEffect <- eventsEffectsLink[, !isWindowEffect, drop = FALSE]
+  whichEventNoWindowEffect <- rowSums(!is.na(whichEventNoWindowEffect))
+  whichEventNoWindowEffect <- c(1, which(whichEventNoWindowEffect > 0))
+
+  hasIgnoreRep <- any(ignoreRepParameter)
+
+  eventsMin <- min(vapply(
+    events[whichEventNoWindowEffect],
+    function(x) min(x$time),
+    double(1)
+  ))
+  eventsMax <- max(vapply(
+    events[whichEventNoWindowEffect],
+    function(x) max(x$time),
+    double(1)
+  ))
   if (is.null(endTime)) {
     endTime <- eventsMax
+    if (any(isWindowEffect)) hasEndTime <- TRUE
   } else if (endTime != eventsMax) {
     if (!is.numeric(endTime)) endTime <- as.numeric(endTime)
-    if (eventsMin > endTime)
+    if (eventsMin > endTime) {
       stop("End time smaller than first event time.", call. = FALSE)
-      # to solve: if endTime > eventsMax
-      # should it produce censored events? warning?
+    }
+    # to solve: if endTime > eventsMax
+    # should it produce censored events? warning?
     # add a fake event to the event list
-    endTimeEvent <- data.frame(
-      time = endTime,
-      sender = NA,
-      receiver = NA,
-      replace = NA
-    )
-    events <- c(events, endtime = list(endTimeEvent))
+    # endTimeEvent <- data.frame(
+    #   time = endTime,
+    #   sender = NA,
+    #   receiver = NA,
+    #   replace = NA
+    # )
+    # events <- c(events, endtime = list(endTimeEvent))
     hasEndTime <- TRUE
   }
   if (is.null(startTime)) {
     startTime <- eventsMin
   } else if (startTime != eventsMin) {
     if (!is.numeric(startTime)) startTime <- as.numeric(startTime)
-    if (eventsMax < startTime)
+    if (eventsMax < startTime) {
       stop("Start time geater than last event time.", call. = FALSE)
+    }
     hasStartTime <- TRUE
     if (eventsMin < startTime) isValidEvent <- FALSE
+    # if (eventsMin > startTime) isValidEvent <- TRUE
     # To solve: if startTime < eventsMin should be a warning?
   }
+  ignoreEvents <- 1L # eventPos should be correct for initialization
 
   # impute missing data in objects: 0 for networks and mean for attributes
   imputed <- imputeMissingData(objectsEffectsLink, envir = prepEnvir)
@@ -104,10 +120,12 @@ preprocess <- function(
   statCache <- initializeCacheStat(
     objectsEffectsLink = objectsEffectsLink, effects = effects,
     groupsNetwork = NULL, windowParameters = windowParameters,
-    n1 = n1, n2 = n2, model = model, subModel = subModel, envir = prepEnvir)
+    n1 = n1, n2 = n2, model = model, subModel = subModel, envir = prepEnvir
+  )
   # We put the initial stats to the previous format of 3 dimensional array
-  initialStats <- array(unlist(lapply(statCache, "[[", "stat")),
-                        dim = c(n1, n2, nEffects)
+  initialStats <- array(
+    unlist(lapply(statCache, "[[", "stat")),
+    dim = c(n1, n2, nEffects)
   )
 
   statCache <- lapply(statCache, "[[", "cache")
@@ -124,19 +142,31 @@ preprocess <- function(
 
   # calculate total of events
   time <- unique(events[[1]]$time)
-  nRightCensoredEvents <- unique(unlist(lapply(events, function(x) x$time)))
-  nTotalEvents  <- as.integer(sum(nRightCensoredEvents <= endTime))
-  nRightCensoredEvents <- setdiff(nRightCensoredEvents, time)
-  if (length(nRightCensoredEvents) > 1) {
-    nRightCensoredEvents <- as.integer(sum(
-      nRightCensoredEvents >= startTime &
-      nRightCensoredEvents <= endTime) - 1)
-  } else nRightCensoredEvents <- 0
-  nDependentEvents <- as.integer(sum(time >= startTime & time <= endTime))
-  if (!rightCensored) nRightCensoredEvents <- 0L
+  if (rightCensored) {
+    nRightCensoredEvents <- unique(unlist(lapply(events, function(x) x$time)))
+    nTotalEvents <- as.integer(sum(nRightCensoredEvents <= endTime))
+    nRightCensoredEvents <- setdiff(nRightCensoredEvents, time)
+    if (length(nRightCensoredEvents) > 1) {
+      nRightCensoredEvents <- as.integer(sum(
+        nRightCensoredEvents >= startTime &
+          nRightCensoredEvents <= endTime
+      ) - 1)
+    } else {
+      nRightCensoredEvents <- 0L
+    }
+  } else {
+    nRightCensoredEvents <- 0L
+    nTotalEvents <- as.integer(nrow(events[[1]]))
+  }
+
+  nDependentEvents <- ifelse(
+    hasStartTime || hasEndTime,
+    as.integer(sum(time >= startTime & time <= endTime)),
+    as.integer(length(time))
+  )
   # CHANGED ALVARO: preallocate objects sizes
   dependentStatistics <- vector("list", nDependentEvents)
-  timeIntervals <- vector("numeric", nDependentEvents)
+  timeIntervals <- vector("numeric", ifelse(rightCensored, nDependentEvents, 0))
   rightCensoredStatistics <- vector("list", nRightCensoredEvents)
   timeIntervalsRightCensored <- vector("numeric", nRightCensoredEvents)
   # CHANGED MARION: added a list that tracks the chronological(ordered by time)
@@ -157,8 +187,9 @@ preprocess <- function(
   # callDependent(439*4), calls(439*4), friendship(766*4))
   pointers <- rep(1, length(events))
   validPointers <- rep(TRUE, length(events))
-  if (hasEndTime)
+  if (hasEndTime) {
     validPointers <- vapply(events, function(x) x$time[1], double(1)) <= endTime
+  }
   pointerTempRightCensored <- 1L
   time <- startTime
   interval <- 0L
@@ -182,26 +213,36 @@ preprocess <- function(
   while (any(validPointers)) {
     iTotalEvents <- iTotalEvents + 1L
     # times: the timepoint for next events to update in all event lists
-    times <- mapply(function(e, p) e[p, ]$time, events, pointers)
+    times <- Map(function(e, p) e[p, ]$time, events, pointers) |>
+      vapply(identity, numeric(1))
     nextEvent <- which(validPointers)[head(which.min(times[validPointers]), 1)]
     nextEventTime <- times[nextEvent]
     if (hasStartTime || hasEndTime) {
-      if (isValidEvent && nextEventTime < endTime) {
-         interval <- nextEventTime - time
-      } else if (isValidEvent && nextEventTime >= endTime) {
-        interval <- nextEventTime - endTime
-      } else if (!isValidEvent && nextEventTime > startTime) {
-        interval <- startTime - nextEventTime
-        isValidEvent <- TRUE
+      if (isValidEvent && nextEventTime <= endTime) {
+        interval <- nextEventTime - time
+      } else if (isValidEvent && nextEventTime > endTime) {
+        interval <- endTime - time
+        nextEventTime <- endTime
         finalStep <- TRUE
+      } else if (!isValidEvent && nextEventTime >= startTime) {
+        interval <- nextEventTime - startTime
+        isValidEvent <- TRUE
       }
-    } else interval <- nextEventTime - time
+    } else {
+      interval <- nextEventTime - time
+    }
 
     time <- nextEventTime
 
-    isDependent <- nextEvent == 1
+    isDependent <- nextEvent == 1 && !finalStep
+
+    if (isValidEvent) {
+      eventPos <- pointers[1] + pointerTempRightCensored - ignoreEvents
+    } else if (isDependent && !isValidEvent) {
+      ignoreEvents <- ignoreEvents + 1L
+      eventPos <- 0
+    }
 
-    eventPos <- pointers[1] + pointerTempRightCensored - 1
     # # CHANGED ALVARO: progress bar
     if (progress && iTotalEvents %% dotEvents == 0) {
       utils::setTxtProgressBar(pb, iTotalEvents)
@@ -223,7 +264,8 @@ preprocess <- function(
     if (isValidEvent && isDependent) {
       iDependentEvents <- 1L + iDependentEvents
       dependentStatistics[[iDependentEvents]] <- updatesDependent
-      timeIntervals[[iDependentEvents]] <- interval
+      if (rightCensored) timeIntervals[[iDependentEvents]] <- interval
+      # timeIntervals[[iDependentEvents]] # correct it for not rate models
       updatesDependent <- vector("list", nEffects)
       updatesIntervals <- vector("list", nEffects)
       # CHANGED MARION: added orderEvents
@@ -240,14 +282,13 @@ preprocess <- function(
         event_sender[[eventPos]] <- event$sender
         event_receiver[[eventPos]] <- event$receiver
       }
-
-    } else {
+    } else if (!isDependent) {
       # 2. store statistic updates for RIGHT-CENSORED
       # (non-dependent, positive) intervals
       if (isValidEvent && rightCensored && interval > 0) {
         # CHANGED MARION: the incremented index was incorrect
-        #rightCensoredStatistics[[ pointers[nextEvent] ]] <- updatesIntervals
-        #timeIntervalsRightCensored[[length(rightCensoredStatistics)]] <-
+        # rightCensoredStatistics[[ pointers[nextEvent] ]] <- updatesIntervals
+        # timeIntervalsRightCensored[[length(rightCensoredStatistics)]] <-
         # interval
         rightCensoredStatistics[[pointerTempRightCensored]] <- updatesIntervals
         timeIntervalsRightCensored[[pointerTempRightCensored]] <- interval
@@ -273,7 +314,10 @@ preprocess <- function(
           event_receiver[[eventPos]] <- event$receiver
         }
         pointerTempRightCensored <- pointerTempRightCensored + 1
-      }
+      } # else if (isValidEvent && !finalStep && interval > 0) {
+      #   timeIntervals[[iDependentEvents + 1]] <- interval +
+      #     timeIntervals[[iDependentEvents + 1]]
+      # }
 
       # 3. update stats and data objects for OBJECT CHANGE EVENTS
       # (all non-dependent events)
@@ -287,7 +331,8 @@ preprocess <- function(
       objectNameTable <- eventsObjectsLink[nextEvent, -1]
       objectName <- objectNameTable$name
       object <- getElementFromDataObjectTable(
-        objectNameTable, envir = prepEnvir
+        objectNameTable,
+        envir = prepEnvir
       )[[1]]
       isUndirectedNet <- FALSE
       if (inherits(object, "network.goldfish")) {
@@ -336,98 +381,118 @@ preprocess <- function(
 
 
       ## 3a. calculate statistics changes
-      if (!finalStep)
+      if (!finalStep) {
         for (id in which(!is.na(eventsEffectsLink[nextEvent, ]))) {
-        # create the ordered list for the objects
-        objectsToPass <- objectsEffectsLink[, id][
-          !is.na(objectsEffectsLink[, id])]
-        names <- rownames(objectsEffectsLink)[!is.na(objectsEffectsLink[, id])]
-        orderedNames <- names[order(objectsToPass)]
-        orderedObjectTable <- getDataObjects(list(list("", orderedNames)))
-        .objects <- getElementFromDataObjectTable(
-          orderedObjectTable,
-          envir = prepEnvir
-        )
-        # identify class to feed effects functions
-        objCat <- assignCatToObject(.objects)
-        attIDs <- which(objCat == "attribute")
-        netIDs <- which(objCat == "network")
-        if (attr(objCat, "noneClass"))
-          stop("An object is not assigned either as network or attibute",
-               paste(names[attr(objCat, "manyClasses") != 1], collapse = ", "),
-               "check the class of the object.", call. = FALSE)
-
-        # call effects function with required arguments
-        .argsFUN <- list(
-          network = if (length(.objects[netIDs]) == 1) {
-            .objects[netIDs][[1]]
-          } else {
-            .objects[netIDs]
-          },
-          attribute = if (length(.objects[attIDs]) == 1) {
-            .objects[attIDs][[1]]
-          } else {
-            .objects[attIDs]
-          },
-          cache = statCache[[id]],
-          n1 = n1,
-          n2 = n2,
-          netUpdate = if (length(.objects[netIDs]) == 1) {
-            NULL
-          } else {
-            which(orderedNames == objectName)
-          },
-          attUpdate = if (length(.objects[attIDs]) == 1) {
-            NULL
-          } else {
-            which(orderedNames == objectName)
+          # create the ordered list for the objects
+          objectsToPass <- objectsEffectsLink[, id][
+            !is.na(objectsEffectsLink[, id])
+          ]
+          names <- rownames(objectsEffectsLink)
+          names <- names[!is.na(objectsEffectsLink[, id])]
+          orderedNames <- names[order(objectsToPass)]
+          orderedObjectTable <- getDataObjects(list(list("", orderedNames)))
+          .objects <- getElementFromDataObjectTable(
+            orderedObjectTable,
+            envir = prepEnvir
+          )
+          # identify class to feed effects functions
+          objCat <- assignCatToObject(.objects)
+          attIDs <- which(objCat == "attribute")
+          netIDs <- which(objCat == "network")
+          if (attr(objCat, "noneClass")) {
+            stop("An object is not assigned either as network or attibute",
+              paste(names[attr(objCat, "manyClasses") != 1], collapse = ", "),
+              "check the class of the object.",
+              call. = FALSE
+            )
           }
-        )
 
-        effectUpdate <- callFUN(
-          effects, id, "effect", c(.argsFUN, event), " cannot update \n",
-          colnames(objectsEffectsLink)[id]
-        )
+          # call effects function with required arguments
+          .argsFUN <- list(
+            network = if (length(.objects[netIDs]) == 1) {
+              .objects[netIDs][[1]]
+            } else {
+              .objects[netIDs]
+            },
+            attribute = if (length(.objects[attIDs]) == 1) {
+              .objects[attIDs][[1]]
+            } else {
+              .objects[attIDs]
+            },
+            cache = statCache[[id]],
+            n1 = n1,
+            n2 = n2,
+            netUpdate = if (length(.objects[netIDs]) == 1) {
+              NULL
+            } else {
+              which(orderedNames == objectName)
+            },
+            attUpdate = if (length(.objects[attIDs]) == 1) {
+              NULL
+            } else {
+              which(orderedNames == objectName)
+            }
+          )
 
-        updates <- effectUpdate$changes
-        # if cache and changes are not null update cache
-        if (!is.null(effectUpdate$cache) && !is.null(effectUpdate$changes)) {
-          statCache[[id]] <- effectUpdate$cache
-        }
-
-        if (isUndirectedNet) {
-          event2 <- event
-          event2$sender <- event$receiver
-          event2$receiver <- event$sender
-          if (!is.null(effectUpdate$cache) && !is.null(effectUpdate$changes))
-            .argsFUN$cache <- statCache[[id]]
-          effectUpdate2 <- callFUN(
-            effects, id, "effect", c(.argsFUN, event2), " cannot update \n",
+          effectUpdate <- callFUN(
+            effects, id, "effect", c(.argsFUN, event), " cannot update \n",
             colnames(objectsEffectsLink)[id]
           )
 
-          if (!is.null(effectUpdate2$cache) && !is.null(effectUpdate2$changes))
-            statCache[[id]] <- effectUpdate2$cache
-          updates2 <- effectUpdate2$changes
-          updates <- rbind(updates, updates2)
-        }
+          updates <- effectUpdate$changes
+          # if cache and changes are not null update cache
+          if (!is.null(effectUpdate$cache) && !is.null(effectUpdate$changes)) {
+            statCache[[id]] <- effectUpdate$cache
+          }
 
-        if (!is.null(updates)) {
-          # CHANGED WEIGUTIAN: UPDATE THE STAT MAT AND IMPUTE THE MISSING VALUES
-          # statCache[[id]][["stat"]][
-          #   cbind(updates[, "node1"], updates[, "node2"])] <-
-          #     updates[, "replace"]
-          # if (anyNA(statCache[[id]][["stat"]])) {
-          #   position_NA <- which(
-          #     is.na(statCache[[id]][["stat"]]),
-          #     arr.ind  = TRUE
-          #   )
-          #   average <- mean(statCache[[id]][["stat"]], na.rm = TRUE)
-          #   updates[is.na(updates[, "replace"]), "replace"] <- average
-          #   statCache[[id]][["stat"]][position_NA] <- average
-          # }
-          updatesDependent[[id]] <- rbind(updatesDependent[[id]], updates)
-          updatesIntervals[[id]] <- rbind(updatesIntervals[[id]], updates)
+          if (isUndirectedNet) {
+            event2 <- event
+            event2$sender <- event$receiver
+            event2$receiver <- event$sender
+            if (!is.null(effectUpdate$cache) &&
+                !is.null(effectUpdate$changes)) { # styler: off
+              .argsFUN$cache <- statCache[[id]]
+            }
+            effectUpdate2 <- callFUN(
+              effects, id, "effect", c(.argsFUN, event2), " cannot update \n",
+              colnames(objectsEffectsLink)[id]
+            )
+
+            if (!is.null(effectUpdate2$cache) &&
+                !is.null(effectUpdate2$changes)) { # styler: off
+              statCache[[id]] <- effectUpdate2$cache
+            }
+            updates2 <- effectUpdate2$changes
+            updates <- rbind(updates, updates2)
+          }
+
+          if (!is.null(updates)) {
+            if (hasStartTime && nextEventTime < startTime) {
+              initialStats[cbind(updates[, "node1"], updates[, "node2"], id)] <-
+                updates[, "replace"]
+            } else {
+              # CHANGED WEIGUTIAN: UPDATE THE STAT MAT
+              # AND IMPUTE THE MISSING VALUES
+              # if (anyNA(statCache[[id]][["stat"]])) {
+              #   position_NA <- which(
+              #     is.na(statCache[[id]][["stat"]]),
+              #     arr.ind  = TRUE
+              #   )
+              #   average <- mean(statCache[[id]][["stat"]], na.rm = TRUE)
+              #   updates[is.na(updates[, "replace"]), "replace"] <- average
+              #   statCache[[id]][["stat"]][position_NA] <- average
+              # }
+
+              updatesDependent[[id]] <- ReduceUpdateNonDuplicates(
+                updatesDependent[[id]],
+                updates
+              )
+              updatesIntervals[[id]] <- ReduceUpdateNonDuplicates(
+                updatesIntervals[[id]],
+                updates
+              )
+            }
+          }
         }
       }
 
@@ -444,7 +509,8 @@ preprocess <- function(
         # Assign object
         assign("object", object, envir = prepEnvir)
         eval(parse(text = paste(objectName, "<- object")),
-             envir = prepEnvir, enclos = parent.frame())
+          envir = prepEnvir, enclos = parent.frame()
+        )
       }
     } # end 3. (!dependent)
 
@@ -458,21 +524,22 @@ preprocess <- function(
     close(pb)
   }
 
-  return(structure(list(
-    initialStats = initialStats,
-    dependentStatsChange = dependentStatistics,
-    rightCensoredStatsChange = rightCensoredStatistics,
-    intervals = timeIntervals,
-    # CHANGED MARION
-    rightCensoredIntervals = timeIntervalsRightCensored,
-    orderEvents = orderEvents,
-    eventTime = event_time,
-    eventSender = event_sender,
-    eventReceiver = event_receiver,
-    startTime = startTime,
-    endTime = endTime
-  ),
-  class = "preprocessed.goldfish"
+  return(structure(
+    list(
+      initialStats = initialStats,
+      dependentStatsChange = dependentStatistics,
+      rightCensoredStatsChange = rightCensoredStatistics,
+      intervals = timeIntervals,
+      # CHANGED MARION
+      rightCensoredIntervals = timeIntervalsRightCensored,
+      orderEvents = orderEvents,
+      eventTime = event_time,
+      eventSender = event_sender,
+      eventReceiver = event_receiver,
+      startTime = startTime,
+      endTime = endTime
+    ),
+    class = "preprocessed.goldfish"
   ))
 }
 
@@ -493,25 +560,27 @@ preprocess <- function(
 #'
 #' @noRd
 initializeCacheStat <- function(
-  objectsEffectsLink, effects,
-  groupsNetwork, windowParameters,
-  n1, n2,
-  model, subModel, envir = environment()) {
+    objectsEffectsLink, effects,
+    groupsNetwork, windowParameters,
+    n1, n2,
+    model, subModel, envir = environment()) {
   objTable <- getDataObjects(list(rownames(objectsEffectsLink)),
-                             removeFirst = FALSE
+    removeFirst = FALSE
   )
   .objects <- getElementFromDataObjectTable(objTable, envir = envir)
   # list of 4, call matrix, friendship matrix, actor$gradetype vector,
   #  actor$floor vector
   objCat <- assignCatToObject(.objects)
-  if (attr(objCat, "noneClass"))
+  if (attr(objCat, "noneClass")) {
     stop(
       "An object is not assigned either as network or attibute",
       paste(rownames(objectsEffectsLink)[attr(objCat, "manyClasses") != 1],
-            collapse = ", "),
+        collapse = ", "
+      ),
       "check the class of the object.",
       call. = FALSE
     )
+  }
 
   # objects: list of 6, each element is a 84*84 matrix
   objectsRet <- lapply(
@@ -534,8 +603,11 @@ initializeCacheStat <- function(
       .argsFUN <- list(
         effectFun = effects[[iEff]][["effect"]],
         network = if (length(networks) == 1) networks[[1]] else networks,
-        attribute = if (length(attributes) == 1)
-          attributes[[1]] else attributes,
+        attribute = if (length(attributes) == 1) {
+          attributes[[1]]
+        } else {
+          attributes
+        },
         groupsNetwork = groupsNetwork,
         window = windowParameters[[iEff]],
         n1 = n1,
@@ -560,7 +632,7 @@ initializeCacheStat <- function(
 #' @param .argsFUN named list with the arguments to feed FUN.
 #' @param error function that returns the error mesage if any.
 #' @param warning function that returns the warning mesage if any.
-#' @param effectLabel character use by the error or warning function to give 
+#' @param effectLabel character use by the error or warning function to give
 #'   an additional information to the user.
 #'
 #' @return the output of call `effects[[effectPos]][[effectType]]`
@@ -572,7 +644,7 @@ initializeCacheStat <- function(
 #'   network = m,
 #'   n1 = 5, n2 = 5,
 #'   sender = 1, receiver = 5, replace = 0
-#'  )
+#' )
 #' effects <- list(list(effect = out))
 #'
 #' ver2 <- callFUN(
@@ -589,7 +661,7 @@ initializeCacheStat <- function(
 #'   effects = effects, effectPos = effectPos, effectType = "effect",
 #'   .argsFUN = .argsFUN, textMss = " ver ",
 #'   effectLabel = "out"
-#'  )
+#' )
 #' }
 callFUN <- function(
     effects, effectPos, effectType, .argsFUN, textMss,
@@ -598,29 +670,33 @@ callFUN <- function(
   warn <- NULL
   .argsNames <- formals(effects[[effectPos]][[effectType]])
   .argsKeep <- pmatch(names(.argsNames), names(.argsFUN))
-    # check for more than one net
+  # check for more than one net
   errorHandler <- function(e) {
     erro <- simpleError(
       paste0(
-        "Effect ", sQuote(effectLabel),
-        " (", effectPos, ") ", textMss, e$message)
+        "Effect ", dQuote(effectLabel),
+        " (", effectPos, ") ", textMss, e$message
+      )
     )
     stop(erro)
   }
-  tryCatch({
-    withCallingHandlers({
-      callRes <- do.call(
-        effects[[effectPos]][[effectType]],
-        .argsFUN[na.omit(.argsKeep)]
-      )},
-      error = identity,
-      warning = function(w) {
-        warn <<- w
-        invokeRestart("muffleWarning")
-      }
-    )
-  },
-  error = errorHandler
+  tryCatch(
+    {
+      withCallingHandlers(
+        {
+          callRes <- do.call(
+            effects[[effectPos]][[effectType]],
+            .argsFUN[na.omit(.argsKeep)]
+          )
+        },
+        error = identity,
+        warning = function(w) {
+          warn <<- w
+          invokeRestart("muffleWarning")
+        }
+      )
+    },
+    error = errorHandler
   )
   if (!is.null(warn)) warning(warn)
   return(callRes)
@@ -663,9 +739,12 @@ callFUN <- function(
 #' )
 #'
 #' objectsEffectsLink <- matrix(
-#'   c(1, NA, NA, 1), nrow = 2, ncol = 2,
-#'   dimnames = list(c("networkAlgo", "actorsEx$attr1"),
-#'                   c("inertia", "alter"))
+#'   c(1, NA, NA, 1),
+#'   nrow = 2, ncol = 2,
+#'   dimnames = list(
+#'     c("networkAlgo", "actorsEx$attr1"),
+#'     c("inertia", "alter")
+#'   )
 #' )
 #' prepEnvir <- environment()
 #'
@@ -674,7 +753,8 @@ callFUN <- function(
 imputeMissingData <- function(objectsEffectsLink, envir = new.env()) {
   # get data object table, row objects columns class (matrix, attribute)
   objTable <- getDataObjects(list(rownames(objectsEffectsLink)),
-                             removeFirst = FALSE)
+    removeFirst = FALSE
+  )
   # print(objTable)
   done <- structure(vector("logical", nrow(objTable)), names = objTable$name)
   for (iEff in seq_len(nrow(objTable))) {
@@ -696,8 +776,25 @@ imputeMissingData <- function(objectsEffectsLink, envir = new.env()) {
       # Assign object
       assign("object", object, envir = envir)
       eval(parse(text = paste(objectName, "<- object")),
-           envir = envir, enclos = parent.frame())
+        envir = envir, enclos = parent.frame()
+      )
     }
   }
   return(done)
 }
+
+ReduceUpdateNonDuplicates <- function(oldUpdates, newUpdates) {
+  if (is.null(newUpdates)) {
+    return(oldUpdates)
+  } else if (!is.null(oldUpdates)) {
+    idsOld <- paste(oldUpdates[, "node1"], oldUpdates[, "node2"], sep = "_")
+    idsNew <- paste(newUpdates[, "node1"], newUpdates[, "node2"], sep = "_")
+
+    return(rbind(
+      oldUpdates[!idsOld %in% idsNew, , drop = FALSE],
+      newUpdates
+    ))
+  } else {
+    return(newUpdates)
+  }
+}
